@@ -17,9 +17,10 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
+
+#include <config.h>
+
+#include <glib/gi18n.h>
 
 #include <signal.h>
 #include <string.h>
@@ -32,31 +33,20 @@
 #include "util.h"
 #include "load-graph.h"
 
+#include "procman_gnomesu.h"
+#include "procman_gksu.h"
+
 static GtkWidget *renice_dialog = NULL;
 static GtkWidget *prefs_dialog = NULL;
 static gint new_nice_value = 0;
 
-/* public */ int kill_signal = SIGTERM;
-
-static void
-cb_show_hide_message_toggled (GtkToggleButton *button, gpointer data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	gboolean toggle_state;
-	
-	toggle_state = gtk_toggle_button_get_active (button);
-
-	gconf_client_set_bool (client, "/apps/procman/hide_message", toggle_state, NULL);
-
-}
 
 static void
 hide_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 {
 	ProcData *procdata = data;
 	
-	if (id == 100) {
+	if (id == GTK_RESPONSE_OK) {
 		add_selected_to_blacklist (procdata);
 	}
 	
@@ -67,251 +57,107 @@ hide_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 void
 procdialog_create_hide_dialog (ProcData *data)
 {
-	ProcData *procdata = data;
-	GtkWidget *messagebox1;
-	GtkWidget *dialog_vbox1, *vbox;
-	GtkWidget *hbox, *hbox1;
-	GtkWidget *dialog_action_area;
-  	GtkWidget *checkbutton1;
-	GtkWidget *button;
-	GtkWidget *image;
-	GtkWidget *label;
-	GtkWidget *align;
-	GtkWidget *icon;
-	const gchar *header  = _("Are you sure you want to hide this process?");
-	const gchar *message = _("If you hide a process, you can unhide it by "
-				 "selecting 'Hidden Processes' in the Edit "
-				 "menu.");
-	gchar *title;
-		  			
-  	messagebox1 = gtk_dialog_new ();
-	
-	gtk_window_set_title (GTK_WINDOW (messagebox1), "");
-	gtk_window_set_resizable (GTK_WINDOW (messagebox1), FALSE);
-	gtk_window_set_modal (GTK_WINDOW (messagebox1), TRUE);
-	
-	gtk_dialog_set_has_separator (GTK_DIALOG (messagebox1), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (messagebox1), 5);
-	
-	dialog_vbox1 = GTK_DIALOG (messagebox1)->vbox;
-	gtk_box_set_spacing (GTK_BOX (dialog_vbox1), 14);
+       ProcData *procdata = data;
+       GtkWidget *hide_alert_dialog;
+       gchar *message;
 
-	hbox = gtk_hbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (dialog_vbox1), hbox, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-	gtk_widget_show (hbox);
+       /*translators: primary alert message*/
+       message = g_strdup_printf (_("Hide the selected process?"));
+       hide_alert_dialog = gtk_message_dialog_new (GTK_WINDOW (procdata->app),
+						   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+						   GTK_MESSAGE_WARNING,
+						   GTK_BUTTONS_NONE,
+						   message);
+       g_free (message);
 
-	image = gtk_image_new_from_stock ("gtk-dialog-warning", GTK_ICON_SIZE_DIALOG);
-	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-	gtk_widget_show (image);
+       /* FIXME: View menu -> Edit menu */
+       /*translators: secondary alert messagex*/
+       message = g_strdup_printf (_("Hidden processes are no longer visible "
+				    "in the process list. You can re-enable "
+				    "them by selecting the \"Hidden Processes\" "
+				    "entry in the View menu."));
+       gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (hide_alert_dialog),
+						 message);
+       g_free (message);
+
+       gtk_dialog_add_buttons (GTK_DIALOG (hide_alert_dialog),
+                               GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                               _("_Hide Process"), GTK_RESPONSE_OK,
+                               NULL);
+       gtk_dialog_set_default_response (GTK_DIALOG (hide_alert_dialog),
+                                        GTK_RESPONSE_OK);
 	
-	vbox = gtk_vbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
-	gtk_widget_show (vbox);
-	
-	title = g_strdup_printf("<b>%s</b>", header);
-	label = gtk_label_new (title);  
-	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_widget_show (label);
-	g_free (title);
-	
-	label = gtk_label_new (_(message));
-	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_widget_show (label);
-	
-	dialog_action_area = GTK_DIALOG (messagebox1)->action_area;
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_END);
-
-	button = gtk_button_new_from_stock ("gtk-cancel");
-  	gtk_widget_show (button);
-  	gtk_dialog_add_action_widget (GTK_DIALOG (messagebox1), button, GTK_RESPONSE_CANCEL);
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-
-  	hbox1 = gtk_hbox_new (FALSE, 0);
-  	gtk_widget_show (hbox1);
-  	gtk_box_pack_end (GTK_BOX (vbox), hbox1, TRUE, TRUE, 0);
-
-  	checkbutton1 = gtk_check_button_new_with_mnemonic (_("_Show this dialog next time"));
-  	gtk_widget_show (checkbutton1);
-  	gtk_box_pack_end (GTK_BOX (hbox1), checkbutton1, FALSE, FALSE, 0);
-    	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton1), TRUE);
-
-	button = gtk_button_new ();
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-		
-	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-	gtk_container_add (GTK_CONTAINER (button), align);
-		
-	hbox = gtk_hbox_new (FALSE, 2);
-	gtk_container_add (GTK_CONTAINER (align), hbox);
-
-	icon = gtk_image_new_from_stock (GTK_STOCK_OK, GTK_ICON_SIZE_BUTTON);
-	gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, FALSE, 0);
+       g_signal_connect (G_OBJECT (hide_alert_dialog), "response",
+			 G_CALLBACK (hide_dialog_button_pressed), procdata);
   	
-	label = gtk_label_new_with_mnemonic (_("_Hide Process"));
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), button);
-	gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-
-	gtk_dialog_add_action_widget (GTK_DIALOG (messagebox1), button, 100);
-  	gtk_dialog_set_default_response (GTK_DIALOG (messagebox1), 100);
-	
-  	g_signal_connect (G_OBJECT (checkbutton1), "toggled",
-                      	  G_CALLBACK (cb_show_hide_message_toggled), procdata);
-        g_signal_connect (G_OBJECT (messagebox1), "response",
-        		  G_CALLBACK (hide_dialog_button_pressed), procdata);
-  	
-  	gtk_widget_show_all (messagebox1);
-
-}
-
-static void
-cb_show_kill_warning_toggled (GtkToggleButton *button, gpointer data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	gboolean toggle_state;
-	
-	toggle_state = gtk_toggle_button_get_active (button);
-	
-	gconf_client_set_bool (client, "/apps/procman/kill_dialog", toggle_state, NULL);	
+       gtk_widget_show_all (hide_alert_dialog);
 
 }
 
 static void
 kill_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 {
-	ProcData *procdata = data;
+	struct KillArgs *kargs = data;
 	
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 
-	if (id == 100) 
-		kill_process (procdata, kill_signal);		
+	if (id == GTK_RESPONSE_OK) 
+		kill_process (kargs->procdata, kargs->signal);
+
+	g_free (kargs);
 }
 
 void
-procdialog_create_kill_dialog (ProcData *data, int signal)
+procdialog_create_kill_dialog (ProcData *procdata, int signal)
 {
-	ProcData *procdata = data;
-	GtkWidget *messagebox1;
-	GtkWidget *dialog_vbox1, *vbox;
-  	GtkWidget *hbox1, *hbox2;
-  	GtkWidget *checkbutton1;
-	GtkWidget *dialog_action_area;
-	GtkWidget *button;
-	GtkWidget *align;
-	GtkWidget *label;
-	GtkWidget *icon;
-	GtkWidget *image;
-  	gchar *text, *title;
-	gchar *header, *message;
-  	
-  	kill_signal = signal;
+	GtkWidget *kill_alert_dialog;
+	gchar *primary, *secondary, *button_text;
+	struct KillArgs *kargs;
+
+	kargs = g_malloc(sizeof *kargs);
+	kargs->procdata = procdata;
+	kargs->signal = signal;
+
   	
   	if (signal == SIGKILL) {
-  		header = _("Are you sure you want to kill this process?");
-		message = _("If you kill a process, unsaved data will be lost.");
-  		text = _("_Kill Process");
+                /*translators: primary alert message*/
+  		primary = _("Kill the selected process?");
+		/*translators: secondary alert message*/
+		secondary = _("Killing a process may destroy data, break the "
+			      "session or introduce a security risk. "
+			      "Only unresponding processes should be killed.");
+  		button_text = _("_Kill Process");
 		  	}
   	else {
-  		header = _("Are you sure you want to end this process?");
-		message = _("If you end a process, unsaved data will be lost.");
-  		text = _("_End Process");
+                /*translators: primary alert message*/
+                primary = _("End the selected process?");
+	        /*translators: secondary alert message*/
+		secondary = _("Ending a process may destroy data, break the "
+			      "session or introduce a security risk. "
+			      "Only unresponding processes should be ended.");
+                button_text = _("_End Process");
   	}
 
-	messagebox1 = gtk_dialog_new ();
-  	
-  	gtk_window_set_title (GTK_WINDOW (messagebox1), "");
-  	gtk_window_set_modal (GTK_WINDOW (messagebox1), TRUE);
-  	gtk_window_set_resizable (GTK_WINDOW (messagebox1), FALSE);
-  
-	gtk_dialog_set_has_separator (GTK_DIALOG (messagebox1), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (messagebox1), 5);
-	
-    	dialog_vbox1 = GTK_DIALOG (messagebox1)->vbox;
-    	gtk_box_set_spacing (GTK_BOX (dialog_vbox1), 14);
-    	
-	hbox1 = gtk_hbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (dialog_vbox1), hbox1, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox1), 5);
-	gtk_widget_show (hbox1);
+	kill_alert_dialog = gtk_message_dialog_new (GTK_WINDOW (procdata->app),
+						    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+						    GTK_MESSAGE_WARNING,
+						    GTK_BUTTONS_NONE,
+						    _(primary));
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (kill_alert_dialog),
+						  _(secondary));
 
-	image = gtk_image_new_from_stock ("gtk-dialog-warning", GTK_ICON_SIZE_DIALOG);
-	gtk_box_pack_start (GTK_BOX (hbox1), image, FALSE, FALSE, 0);
-	gtk_widget_show (image);
-	
-	vbox = gtk_vbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (hbox1), vbox, TRUE, TRUE, 0);
-	gtk_widget_show (vbox);
-	
-	title = g_strconcat ("<b>", _(header), "</b>", NULL);
-	label = gtk_label_new (title);  
-	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_widget_show (label);
-	g_free (title);
-	
-	label = gtk_label_new (_(message));
-	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_widget_show (label);
-	
-	dialog_action_area = GTK_DIALOG (messagebox1)->action_area;
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_END);
+	gtk_dialog_add_buttons (GTK_DIALOG (kill_alert_dialog),
+				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				_(button_text), GTK_RESPONSE_OK,
+				NULL);
 
-	button = gtk_button_new_from_stock ("gtk-cancel");
-  	gtk_widget_show (button);
-  	gtk_dialog_add_action_widget (GTK_DIALOG (messagebox1), button, GTK_RESPONSE_CANCEL);
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_dialog_set_default_response (GTK_DIALOG (kill_alert_dialog),
+					 GTK_RESPONSE_CANCEL);
 
-  	hbox2 = gtk_hbox_new (FALSE, 0);
-  	gtk_widget_show (hbox2);
-  	gtk_box_pack_end (GTK_BOX (vbox), hbox2, TRUE, TRUE, 0);
-
-  	checkbutton1 = gtk_check_button_new_with_mnemonic (_("_Show this dialog next time"));
-  	gtk_widget_show (checkbutton1);
-  	gtk_box_pack_end (GTK_BOX (hbox2), checkbutton1, FALSE, FALSE, 0);
-    	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton1), TRUE);
-
-	button = gtk_button_new ();
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-		
-	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-	gtk_container_add (GTK_CONTAINER (button), align);
-		
-	hbox1 = gtk_hbox_new (FALSE, 2);
-	gtk_container_add (GTK_CONTAINER (align), hbox1);
-
-	icon = gtk_image_new_from_stock (GTK_STOCK_OK, GTK_ICON_SIZE_BUTTON);
-	gtk_box_pack_start (GTK_BOX (hbox1), icon, FALSE, FALSE, 0);
-
-	label = gtk_label_new_with_mnemonic (_(text));
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), button);
-	gtk_box_pack_end (GTK_BOX (hbox1), label, FALSE, FALSE, 0);
-
-	gtk_dialog_add_action_widget (GTK_DIALOG (messagebox1), button, 100);
-  	gtk_dialog_set_default_response (GTK_DIALOG (messagebox1), 100);	
-					    
-  	g_signal_connect (G_OBJECT (checkbutton1), "toggled",
-                      	  G_CALLBACK (cb_show_kill_warning_toggled),
-                      	  procdata);
-        g_signal_connect (G_OBJECT (messagebox1), "response",
-        		  G_CALLBACK (kill_dialog_button_pressed), procdata);
-        
-        gtk_widget_show_all (messagebox1);
-        
+        g_signal_connect (G_OBJECT (kill_alert_dialog), "response",
+        		  G_CALLBACK (kill_dialog_button_pressed), kargs);
         
+        gtk_widget_show_all (kill_alert_dialog);
 }
 
 static gchar *
@@ -347,7 +193,7 @@ renice_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 	if (id == 100) {
 		if (new_nice_value == -100)
 			return;		
-		renice (procdata, -2, new_nice_value);
+		renice(procdata, new_nice_value);
 	}
 	
 	gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -355,9 +201,8 @@ renice_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 }
 
 void
-procdialog_create_renice_dialog (ProcData *data)
+procdialog_create_renice_dialog (ProcData *procdata)
 {
-	ProcData *procdata = data;
 	ProcInfo *info = procdata->selected_process;
 	GtkWidget *dialog = NULL;
 	GtkWidget *dialog_vbox;
@@ -425,7 +270,7 @@ procdialog_create_renice_dialog (ProcData *data)
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 2,
 			  0, 0, 0, 0);
 	
-	renice_adj = gtk_adjustment_new (info->nice, -20, 20, 1, 1, 0);
+	renice_adj = gtk_adjustment_new (info->nice, RENICE_VAL_MIN, RENICE_VAL_MAX, 1, 1, 0);
 	new_nice_value = 0;
 	hscale = gtk_hscale_new (GTK_ADJUSTMENT (renice_adj));
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), hscale);
@@ -464,31 +309,6 @@ prefs_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
 	prefs_dialog = NULL;
 }
 
-static void
-show_tree_toggled (GtkToggleButton *button, gpointer data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	gboolean toggled;
-	
-	toggled = gtk_toggle_button_get_active (button);
-	gconf_client_set_bool (client, "/apps/procman/show_tree", toggled, NULL);
-
-}
-
-static void
-show_threads_toggled (GtkToggleButton *button, gpointer data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	
-	gboolean toggled;
-	
-	toggled = gtk_toggle_button_get_active (button);
-	
-	gconf_client_set_bool (client, "/apps/procman/show_threads", toggled, NULL);
-		
-}
 
 static void
 show_kill_dialog_toggled (GtkToggleButton *button, gpointer data)
@@ -504,6 +324,36 @@ show_kill_dialog_toggled (GtkToggleButton *button, gpointer data)
 		
 }
 
+
+static void
+smooth_refresh_toggled(GtkToggleButton *button, gpointer data)
+{
+	ProcData *procdata = data;
+	GConfClient *client = procdata->client;
+
+	gboolean toggled;
+
+	toggled = gtk_toggle_button_get_active(button);
+
+	gconf_client_set_bool(client, SMOOTH_REFRESH_KEY, toggled, NULL);
+}
+
+
+
+static void
+show_all_fs_toggled (GtkToggleButton *button, gpointer data)
+{
+	ProcData *procdata = data;
+	GConfClient *client = procdata->client;
+
+	gboolean toggled;
+
+	toggled = gtk_toggle_button_get_active (button);
+
+	gconf_client_set_bool (client, "/apps/procman/show_all_fs", toggled, NULL);
+}
+
+
 static void
 show_hide_dialog_toggled (GtkToggleButton *button, gpointer data)
 {
@@ -573,18 +423,6 @@ update_disks_update_interval (GtkWidget *widget, GdkEventFocus *event, gpointer
 }
 
 
-static void
-proc_field_toggled (GtkToggleButton *button, gpointer data)
-{
-	GtkTreeViewColumn *column = data;
-	gboolean toggled;
-	
-	toggled = gtk_toggle_button_get_active (button);
-
-	gtk_tree_view_column_set_visible (column, toggled);
-	
-}
-
 static void
 field_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
 {
@@ -614,14 +452,19 @@ create_proc_field_page (ProcData *procdata)
 {
 	GtkWidget *vbox;
 	GtkWidget *scrolled;
+	GtkWidget *label;
 	GtkWidget *tree = procdata->tree, *treeview;
-	GList *columns = NULL;
+	GList *it, *columns;
 	GtkListStore *model;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *cell;
 
 	vbox = gtk_vbox_new (FALSE, 6);
 	
+	label = gtk_label_new_with_mnemonic (_("Processes i_nfo showed in list:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
+
 	scrolled = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
                                   	GTK_POLICY_AUTOMATIC,
@@ -634,6 +477,7 @@ create_proc_field_page (ProcData *procdata)
 	treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
 	gtk_container_add (GTK_CONTAINER (scrolled), treeview);
 	g_object_unref (G_OBJECT (model));
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), treeview);
 	
 	column = gtk_tree_view_column_new ();
 	
@@ -660,8 +504,9 @@ create_proc_field_page (ProcData *procdata)
 	
 	columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (tree));
 	
-	while (columns) {
-		GtkTreeViewColumn *column = columns->data;
+	for(it = columns; it; it = it->next)
+	{
+		GtkTreeViewColumn *column = it->data;
 		GtkTreeIter iter;
 		const gchar *title;
 		gboolean visible;
@@ -674,11 +519,9 @@ create_proc_field_page (ProcData *procdata)
 		
 		gtk_list_store_append (model, &iter);
 		gtk_list_store_set (model, &iter, 0, visible, 1, title, 2, column,-1);
-			    
-		
-		columns = g_list_next (columns);
 	}
-		
+
+	g_list_free(columns);
 
 	return vbox;
 }
@@ -699,20 +542,27 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	GtkWidget *check_button;
 	GtkWidget *tab_label;
 	GtkWidget *color_picker;
+	GtkWidget *smooth_button;
 	GtkSizeGroup *size;
 	gfloat update;
 	gchar *tmp;
+	GdkColor color;
 	
 	if (prefs_dialog)
 		return;
 		
 	size = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	
-	dialog = gtk_dialog_new_with_buttons (_("Preferences"), NULL,
+	dialog = gtk_dialog_new_with_buttons (_("System Monitor Preferences"),
+					      GTK_WINDOW (procdata->app),
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 					      NULL);
-	gtk_window_set_default_size (GTK_WINDOW (dialog), 400,  375);
+	/* FIXME: we should not declare the window size, but let it's   */
+	/* driven by window childs. The problem is that the fields list */
+	/* have to show at least 4 items to respect HIG. I don't know   */
+	/* any function to set list height by contents/items inside it. */
+	gtk_window_set_default_size (GTK_WINDOW (dialog), 400, 420);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	prefs_dialog = dialog;
@@ -726,7 +576,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	
 	proc_box = gtk_vbox_new (FALSE, 18);
 	gtk_container_set_border_width (GTK_CONTAINER (proc_box), 12);
-	tab_label = gtk_label_new (_("Process Listing"));
+	tab_label = gtk_label_new (_("Processes"));
 	gtk_widget_show (tab_label);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), proc_box, tab_label);
 	
@@ -760,8 +610,13 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (hbox2), hbox3, TRUE, TRUE, 0);
 	
 	update = (gfloat) procdata->config.update_interval;
-	adjustment = (GtkAdjustment *) gtk_adjustment_new(update / 1000.0, 1.0, 
-							  100.0, 0.25, 1.0, 1.0);
+	adjustment = (GtkAdjustment *) gtk_adjustment_new(update / 1000.0,
+							  MIN_UPDATE_INTERVAL / 1000,
+							  MAX_UPDATE_INTERVAL / 1000,
+							  0.25,
+							  1.0,
+							  1.0);
+
 	spin_button = gtk_spin_button_new (adjustment, 1.0, 2);
 	gtk_box_pack_start (GTK_BOX (hbox3), spin_button, TRUE, TRUE, 0);
 	g_signal_connect (G_OBJECT (spin_button), "focus_out_event",
@@ -771,11 +626,26 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	label = gtk_label_new_with_mnemonic (_("seconds"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_box_pack_start (GTK_BOX (hbox3), label, FALSE, FALSE, 0);
-	
+
+
+	hbox2 = gtk_hbox_new(FALSE, 6);
+	gtk_box_pack_start(GTK_BOX(vbox2), hbox2, FALSE, FALSE, 0);
+
+	smooth_button = gtk_check_button_new_with_mnemonic(_("Enable _smooth refresh"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(smooth_button),
+				     gconf_client_get_bool(procdata->client,
+							   SMOOTH_REFRESH_KEY,
+							   NULL));
+	g_signal_connect(G_OBJECT(smooth_button), "toggled",
+			 G_CALLBACK(smooth_refresh_toggled), procdata);
+	gtk_box_pack_start(GTK_BOX(vbox2), smooth_button, TRUE, TRUE, 0);
+
+
+
 	hbox2 = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 		
-	check_button = gtk_check_button_new_with_mnemonic (_("Show warning dialog when ending or _killing processes"));
+	check_button = gtk_check_button_new_with_mnemonic (_("Alert before ending or _killing processes"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button), 
 				      procdata->config.show_kill_warning);
 	g_signal_connect (G_OBJECT (check_button), "toggled",
@@ -785,7 +655,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	hbox2 = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 	
-	check_button = gtk_check_button_new_with_mnemonic (_("Show warning dialog when _hiding processes"));
+	check_button = gtk_check_button_new_with_mnemonic (_("Alert before _hiding processes"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button), 
 				    procdata->config.show_hide_message);
 	g_signal_connect (G_OBJECT (check_button), "toggled",
@@ -813,7 +683,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	
 	sys_box = gtk_vbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (sys_box), 12);
-	tab_label = gtk_label_new (_("Resource Monitor"));
+	tab_label = gtk_label_new (_("Resources"));
 	gtk_widget_show (tab_label);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sys_box, tab_label);
 	
@@ -868,14 +738,14 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
 	gtk_size_group_add_widget (size, label);
 	
-	color_picker = gnome_color_picker_new ();
-	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (color_picker), 
-				    procdata->config.bg_color.red,
-				    procdata->config.bg_color.green,
-				    procdata->config.bg_color.blue, 0);
+	color.red   = procdata->config.bg_color.red;
+	color.green = procdata->config.bg_color.green;
+   	color.blue  = procdata->config.bg_color.blue;
+	color_picker = gtk_color_button_new_with_color (&color);
+
 	g_signal_connect (G_OBJECT (color_picker), "color_set",
 			          G_CALLBACK (cb_bg_color_changed), procdata);
-	gtk_box_pack_start (GTK_BOX (hbox2), color_picker,TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox2), color_picker, FALSE, FALSE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_picker);
 	gtk_widget_show (color_picker);
 		
@@ -887,26 +757,33 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
 	gtk_size_group_add_widget (size, label);
 	
-	color_picker = gnome_color_picker_new ();
-	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (color_picker), 
-				    procdata->config.frame_color.red,
-				    procdata->config.frame_color.green,
-				    procdata->config.frame_color.blue, 0);
+	color.red   = procdata->config.frame_color.red;
+	color.green = procdata->config.frame_color.green;
+   	color.blue  = procdata->config.frame_color.blue;
+	color_picker = gtk_color_button_new_with_color (&color);
+	
 	g_signal_connect (G_OBJECT (color_picker), "color_set",
 			    G_CALLBACK (cb_frame_color_changed), procdata);	  
-	gtk_box_pack_start (GTK_BOX (hbox2), color_picker, TRUE, TRUE, 0);	
+	gtk_box_pack_start (GTK_BOX (hbox2), color_picker, FALSE, FALSE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_picker);
 	gtk_widget_show (color_picker);
-	
+
+
+	/*
+	 * Devices
+	 */
 	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (sys_box), vbox, FALSE, FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
+	tab_label = gtk_label_new (_("Devices"));
+	gtk_widget_show (tab_label);
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, tab_label);
 	
 	tmp = g_strdup_printf ("<b>%s</b>", _("Devices"));
 	label = gtk_label_new (NULL);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_label_set_markup (GTK_LABEL (label), tmp);
 	g_free (tmp);
-	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 	
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
@@ -923,7 +800,6 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	label = gtk_label_new_with_mnemonic (_("Update _interval:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
-	gtk_size_group_add_widget (size, label);
 	
 	hbox3 = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (hbox2), hbox3, TRUE, TRUE, 0);
@@ -940,7 +816,19 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	label = gtk_label_new_with_mnemonic (_("seconds"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_box_pack_start (GTK_BOX (hbox3), label, FALSE, FALSE, 0);
-	
+
+
+	hbox2 = gtk_hbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
+	check_button = gtk_check_button_new_with_mnemonic (_("Show _all filesystems"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button),
+				      procdata->config.show_all_fs);
+	g_signal_connect (G_OBJECT (check_button), "toggled",
+			    G_CALLBACK (show_all_fs_toggled), procdata);
+	gtk_box_pack_start (GTK_BOX (hbox2), check_button, FALSE, FALSE, 0);
+
+
+
 	gtk_widget_show_all (dialog);
 	g_signal_connect (G_OBJECT (dialog), "response",
 				  G_CALLBACK (prefs_dialog_button_pressed), procdata);
@@ -951,117 +839,53 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 1);
 }
 
-static void
-entry_activate_cb (GtkEntry *entry, gpointer data)
+
+
+static char *
+procman_action_to_command(ProcmanActionType type,
+			  gint pid,
+			  gint extra_value)
 {
-	GtkDialog *dialog = GTK_DIALOG (data);
-	
-	gtk_dialog_response (dialog, 100);
-	
-}	
-
-/*
-** type determines whether if dialog is for killing process (type=0) or renice (type=other).
-** extra_value is not used for killing and is priority for renice
-*/
-void procdialog_create_root_password_dialog (gint type, ProcData *procdata, gint pid, 
-					     gint extra_value, gchar *text)
-{
-	GtkWidget *dialog;
-	GtkWidget *error_dialog;
-	GtkWidget *main_vbox;
-	GtkWidget *hbox;
-	GtkWidget *entry;
-	GtkWidget *label;
-	gchar *title = NULL, *button_label;
-	gchar *command;
-	gchar *password, *blank;
-	gint retval;
-
-	if (type == 0) {
-		if (extra_value == SIGKILL) {
-			title = g_strdup (_("Kill Process"));
-			button_label = g_strdup (_("_Kill Process"));
-		}
-		else {
-			title = g_strdup (_("End Process"));
-			button_label = g_strdup (_("_End Process"));
-		}
+	switch (type) {
+	case PROCMAN_ACTION_KILL:
+	       return g_strdup_printf("kill -s %d %d", extra_value, pid);
+	case PROCMAN_ACTION_RENICE:
+		return g_strdup_printf("renice %d %d", extra_value, pid);
+	default:
+		g_assert_not_reached();
 	}
-	else {
-		title = g_strdup (_("Change Priority"));
-		button_label = g_strdup (_("Change _Priority"));
-	}
-		
-	dialog = gtk_dialog_new_with_buttons (title, NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					      button_label, 100,
-					      NULL);
-	
-	main_vbox = GTK_DIALOG (dialog)->vbox;
-	
-	label = gtk_label_new (_(text));
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD, 2 * GNOME_PAD);
-	gtk_box_pack_start (GTK_BOX (main_vbox), label, FALSE, FALSE, 0);
-	
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), GNOME_PAD_SMALL);
-	gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, FALSE, 0);
-	
-	label = gtk_label_new (_("Root Password :"));
-	gtk_misc_set_padding (GTK_MISC (label), GNOME_PAD_SMALL, 0);
-	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, FALSE, 0);
-	
-	entry = gtk_entry_new ();
-	gtk_entry_set_visibility (GTK_ENTRY (entry), FALSE);
-	gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, FALSE, 0);
-	g_signal_connect (G_OBJECT (entry), "activate",
-			  G_CALLBACK (entry_activate_cb), dialog);
-		
-	gtk_widget_show_all (main_vbox);
-	
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
-	gtk_widget_grab_focus (entry);
-		
-	g_free (title);	
-	g_free (button_label);
-	
-	retval = gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_hide (dialog);
-	
-	if (retval == 100) {
-		password = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
-		
-		if (!password)
-			password = "";
-		blank = g_strdup (password);
-		if (strlen (blank))
-			memset (blank, ' ', strlen (blank));
-			
-		gtk_entry_set_text (GTK_ENTRY (entry), blank);
-		gtk_entry_set_text (GTK_ENTRY (entry), "");
-		g_free (blank);
-		
-		if (type == 0)
-			command = g_strdup_printf ("kill -s %d %d", extra_value, pid);
-		else
-			command = g_strdup_printf ("renice %d %d", extra_value, pid);
-			
-		if (su_run_with_password (command, password) == -1) {
-			error_dialog = gtk_message_dialog_new (NULL,
-							       GTK_DIALOG_DESTROY_WITH_PARENT,
-                                  			       GTK_MESSAGE_ERROR,
-                                  			       GTK_BUTTONS_OK,
-                                  			       "%s",
-                                  			      _("Wrong Password.")); 
-			gtk_dialog_run (GTK_DIALOG (error_dialog));
-			gtk_widget_destroy (error_dialog);
-		}
-		g_free (command);
-		
-	}
-	gtk_widget_destroy (dialog);
-
 }
 
+
+/*
+ * type determines whether if dialog is for killing process or renice.
+ * type == PROCMAN_ACTION_KILL,   extra_value -> signal to send
+ * type == PROCMAN_ACTION_RENICE, extra_value -> new priority.
+ */
+gboolean
+procdialog_create_root_password_dialog(ProcmanActionType type,
+				       ProcData *procdata,
+				       gint pid,
+				       gint extra_value)
+{
+	char * command;
+	gboolean ret = FALSE;
+
+	command = procman_action_to_command(type, pid, extra_value);
+
+	ret = procman_gksu_create_root_password_dialog(command);
+
+	if (ret)
+		goto out;
+
+	ret = procman_gnomesu_create_root_password_dialog(command);
+
+	if (ret)
+		goto out;
+
+ out:
+	g_free(command);
+	return ret;
+}
+
+
